.meta {
    display:none;
}

#media-list {
    margin-right:160px !important;
    width:auto !important;
    padding: 5px 165px 5px 5px;
    border-right:1px solid #DDDDDD;
}

.media-object {
    float:left;
    width:180px;
    height:160px;
    overflow:hidden;
    margin: 5px;
    padding: 5px;
    border:1px solid #d8d8d8;
    cursor:pointer;
}

.media-object.hover {
    border:1px solid #000000;
}

.media-object.selected {
    background-color:#ffff88;
}

.media-object.matched {
    display:block;
}

.media-object .preview,
.media-object .name {
    text-align:center;
}

.paginator {
    clear:both;
}
