.mediatype {
    float:left;
    margin:1em;
    padding:1em;
    vertical-align:middle;
    width:18em;
    height:18em;
}

.mediatype .icon {
    text-align:center;
}

.mediatype .label {
    font-weight:bold !important;
    text-align:center;
}
.mediatype label {
    display:inline;
    float:none;
    font-size:1.3em;
}

input[name=_addanother], input[name=_continue] {
    display:none;
}

.aligned label {
    padding-bottom:0.5em;
    width:100%;
    float:none;
}

form .mediatype p.help {
    margin:0.5em 1em;
    padding-left:0px;
    padding-right:0px;
    text-align:center;
}
